
#ifndef _C147_ds7308_
#define _C147_ds7308_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER_32 F6519_87660(EIF_REFERENCE);
extern EIF_INTEGER_32 F6519_87663(EIF_REFERENCE, EIF_INTEGER_32);
extern void EIF_Minit7308(void);

#ifdef __cplusplus
}
#endif

#endif
